/*    arkanoid is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
      the Free Software Foundation, either version 3 of the License, or
      (at your option) any later version.

      arkanoid is distributed in the hope that it will be useful,
      but WITHOUT ANY WARRANTY; without even the implied warranty of
      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
      GNU General Public License for more details.

      You should have received a copy of the GNU General Public License
      along with arkanoid.  If not, see <http://www.gnu.org/licenses/>.

*/


#include <SFML/Graphics.hpp>
#include <math.h>
#include <iostream>
#include <fstream>

#include "ball.h"
#include "brick.h"
#include "wall.h"

#define WIDTH 600
#define HEIGHT 600

sf::Clock chrono;
bool show_msg=false;

int main(int argc, char** argv)
{
	sf::RenderWindow window(sf::VideoMode(WIDTH,HEIGHT),"ARKANOID EDITOR");
	sf::Event event;

	sf::Font font;
	font.loadFromFile("font/AtariST8x16SystemFont.ttf");

	sf::Text msg;
	msg.setString("Livello salvato!");
	msg.setFont(font);
	msg.setFillColor(sf::Color::White);
	msg.setPosition(WIDTH/2-120,HEIGHT/2+100);

	wall grid;
	grid.generateGrid();
	std::vector<brick> bricks=grid.getBricksVector();


	while(window.isOpen())
	{
		while(window.pollEvent(event))
		{
			if(event.type == sf::Event::Closed) window.close();

			if(sf::Mouse::isButtonPressed(sf::Mouse::Left))
			{
				sf::Vector2i mouse_position=sf::Mouse::getPosition(window);

				for(auto &brick : bricks)
				{
					if(brick.getGlobalBounds().contains(sf::Vector2f(mouse_position)))
					{
						brick.setResistance();
						brick.updateStatus();
					}

					grid.setBricksVector(bricks);
					grid.count_total_bricks();
				}

			}


			if(sf::Keyboard::isKeyPressed(sf::Keyboard::Space))
			{
				std::ofstream serializer;

				if(argv[1]) serializer.open(argv[1]);
				else serializer.open("mio_lv");

				for(auto &brick : bricks)
				{
					if(brick.getResistance() != 0)
					{
						serializer << brick.getX();
						serializer << ","<<brick.getY();
						serializer << ","<<brick.getResistance();
						serializer << "\n";

					}
				}
				show_msg=true;
				chrono.restart();
			}

		}

		window.clear();
		grid.draw(window);
		if(show_msg && chrono.getElapsedTime().asSeconds() < 2) window.draw(msg);
		else show_msg=false;
		window.display();
	}
	return 0;
}

